using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Web.UI;
using System.Threading;
using System.Globalization;

namespace CSSamples.Samples
{
    public partial class DisplayASimpleMap : System.Web.UI.Page, ICallbackEventHandler
    {
        private string callbackResult;

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
                Map1.CustomOverlays.Add(worldMapKitOverlay);

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/SampleData/usa/states.shp"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay staticOverlay = new LayerOverlay("WorldStaticOverlay");
                staticOverlay.IsBaseOverlay = false;
                staticOverlay.Layers.Add("WorldLayer", worldLayer);
                Map1.CustomOverlays.Add(staticOverlay);
            }

            Page.ClientScript.RegisterClientScriptBlock(this.GetType(), "GetBBOXCallback", "getBoundingBox", true);
        }

        public string GetCallbackResult()
        {
            return callbackResult;
        }

        public void RaiseCallbackEvent(string eventArgument)
        {
            if (!String.IsNullOrEmpty(eventArgument))
            {
                ShapeFileFeatureLayer layer = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays["WorldStaticOverlay"]).Layers[eventArgument];
                Monitor.Enter(layer);
                if (!layer.IsOpen) layer.Open();
                RectangleShape bbox = layer.GetBoundingBox();
                callbackResult = String.Format(CultureInfo.InvariantCulture, "{{l:{0},t:{1},r:{2},b:{3}}}", bbox.UpperLeftPoint.X, bbox.UpperLeftPoint.Y, bbox.LowerRightPoint.X, bbox.LowerRightPoint.Y);
            }
        }
    }
}
